@@ -24,6 +24,7 @@ def url_to_module(url):
         'bilibili': bilibili,
         'cntv': cntv,
         'dailymotion': dailymotion,
+        'douban': douban,
         'facebook': facebook,
         'google': googleplus,
         'iask': sina,
@@ -33,6 +34,7 @@ def url_to_module(url):
         'jpopsuki': jpopsuki,
         'kankanews': bilibili,
         'ku6': ku6,
+        'miomio': miomio,
         'mixcloud': mixcloud,
         'nicovideo': nicovideo,
         'pptv': pptv,
