@@ -4,6 +4,7 @@ from .acfun import *
 from .bilibili import *
 from .cntv import *
 from .dailymotion import *
+from .douban import *
 from .facebook import *
 from .googleplus import *
 from .ifeng import *
@@ -11,6 +12,7 @@ from .iqiyi import *
 from .joy import *
 from .jpopsuki import *
 from .ku6 import *
+from .miomio import *
 from .mixcloud import *
 from .netease import *
 from .nicovideo import *
